14.74. cdist-type__letsencrypt_cert(7) — cdist 4.8.1 documentation

# 14.74. cdist-type__letsencrypt_cert(7)

## 14.74.1. NAME

cdist-type__letsencrypt_cert - Get an SSL certificate from Let's Encrypt

## 14.74.2. DESCRIPTION

Automatically obtain a Let's Encrypt SSL certificate. Uses certbot's webroot method. You must set up your web server to work with webroot.

## 14.74.3. REQUIRED PARAMETERS

webroot
  The path to your webroot, as set up in your webserver config.
admin-email
  Where to send Let's Encrypt emails like "certificate needs renewal".

## 14.74.4. OPTIONAL PARAMETERS

None.

## 14.74.5. OPTIONAL MULTIPLE PARAMETERS

renew-hook
  Renew hook command directly passed to certbot in cron job.

## 14.74.6. EXAMPLES

    __letsencrypt_cert example.com --admin-email root@example.com --webroot /data/letsencrypt/root

    __letsencrypt_cert example.com --admin-email root@example.com --webroot /data/letsencrypt/root --renew-hook "service nginx reload"

## 14.74.7. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>
Kamila Součková <kamila--@--ksp.sk>
Darko Poljak <darko.poljak--@--gmail.com>

## 14.74.8. COPYING

Copyright (C) 2017 Nico Schottelius, Kamila Součková, Darko Poljak. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.